@@ -1,5 +1,6 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 ##
+## Copyright (C) 2008-2019, Nigel Stewart <nigels[]users sourceforge net>
 ## Copyright (C) 2002-2008, Marcelo E. Magallon <mmagallo[]debian org>
 ## Copyright (C) 2002-2008, Milan Ikits <milan ikits[]ieee org>
 ##
@@ -9,6 +10,7 @@
 
 use strict;
 use warnings;
+use File::Basename;
 
 use lib '.';
 do 'bin/make.pl';
@@ -27,7 +29,7 @@ if (@ARGV)
 {
 	@extlist = @ARGV;
 
-	foreach my $ext (sort @extlist)
+	foreach my $ext (sort { basename($a) cmp basename($b) } @extlist)
 	{
 		my ($extname, $exturl, $extstring, $reuse, $types, $tokens, $functions, $exacts) = 
 			parse_ext($ext);
